@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2020-12-25 10:04:58
+:LastEditTime: 2021-01-06 18:43:31
 :LastEditors: ChenXiaolei
 :Description: StudioBaseHandler
 """
@@ -15,6 +15,7 @@ from seven_studio.models.db_models.user.user_info_model import *
 from seven_studio.models.db_models.menu.menu_info_model_ex import *
 from seven_studio.models.db_models.role.role_user_model import *
 from seven_studio.models.db_models.role.role_power_model_ex import *
+from seven_studio.models.db_models.log.log_action_model import *
 from seven_studio.models.seven_model import PageInfo
 from seven_studio.models.enum import *
 
@@ -32,6 +33,35 @@ class StudioBaseHandler(BaseCookieHandler):
     def check_xsrf_cookie(self):
         return
 
+    def add_action_log(self, module_code, content, record_time=None):
+        """
+        :description: 添加平台操作行为日志
+        :param module_code: 模块标识
+        :param content: 日志内容
+        :param record_time: 日志时间 默认当前时间
+        :return 成功 True 失败 False
+        :last_editors: ChenXiaolei
+        """
+        op_result = False
+        try:
+            if not record_time:
+                record_time = TimeHelper.get_now_timestamp()
+            user_id = self.request_user_id()
+            client_ip = self.get_remote_ip()
+            log_action = LogAction()
+            log_action.module_code = module_code
+            log_action.user_id = user_id
+            log_action.content = content
+            log_action.record_time = record_time
+            log_action.client_ip = client_ip
+
+            if LogActionModel().add_entity(log_action) > 0:
+                op_result = True
+            return op_result
+        except:
+            self.logger_error.error(f"添加品台行为日志时异常:{traceback.format_exc()}")
+            return False
+
     def json_dumps(self, rep_dic):
         """
         :description: 用于将字典形式的数据转化为字符串
@@ -259,7 +289,7 @@ class StudioBaseHandler(BaseCookieHandler):
         page_info = PageInfo()
         page_info.PageIndex = page_index
         page_info.PageSize = page_size
-        page_info.RecordCount = total if total>0 else len(p_dict)
+        page_info.RecordCount = total if total > 0 else len(p_dict)
         page_info.Data = p_dict
         page_info = page_info.get_entity_by_page_info(page_info)
         return page_info.__dict__
